@@ -8,6 +8,10 @@ class Dependency:
 
     def __init__(self):
         self.manager = Manager()
+        self.get = self.manager.get_prod
+        self.get_history = self.manager.get_history
+        self.list_history = self.manager.list_history
+        self.clear_history = self.manager.clear_history
 
     def currents(self, raw=False):
         json_data = self.manager.get_naas()
@@ -20,32 +24,6 @@ class Dependency:
                 if item["type"] == self.role:
                     print(f"File ==> {item['path']}")
 
-    def get(self, path=None):
-        if not self.manager.notebook_path():
-            print("No get done you are in already in naas folder\n")
-            return
-        current_file = self.manager.get_path(path)
-        self.manager.get_prod(current_file)
-
-    def get_history(self, histo, path=None):
-        if not self.manager.notebook_path():
-            print("No get history done you are in already in naas folder\n")
-            return
-        current_file = self.manager.get_path(path)
-        self.manager.get_history(current_file, histo)
-
-    def list_history(self, path=None):
-        current_file = self.manager.get_path(path)
-        self.manager.list_history(current_file)
-
-    def clear_history(self, path=None, histo=None):
-        if not self.manager.notebook_path():
-            print("No clear history done you are in already in naas folder\n")
-            return
-        current_file = self.manager.get_path(path)
-        self.manager.clear_history(current_file, histo)
-        print("🕣 Your Dependency history has been remove from production folder.\n")
-
     def add(self, path=None, debug=False):
         if not self.manager.notebook_path():
             print("No add done you are in already in naas folder\n")
@@ -71,7 +49,7 @@ class Dependency:
         self.manager.del_prod({"type": self.role, "path": current_file}, not debug)
         print("🗑 Done! Your Dependency has been remove from production folder.\n")
         if all is True:
-            self.manager.clear_history(current_file)
+            self.clear_history(path)
 
     def help(self):
         print(f"=== {type(self).__name__} === \n")
