@@ -143,7 +143,7 @@ class Manager:
     def __copy_file_in_dev(self, path):
         new_path = self.get_prod_path(path)
         if not os.path.exists(new_path):
-            raise Exception(f"file doesn't exist {new_path}")
+            raise FileNotFoundError(f"file doesn't exist {new_path}")
         if not os.path.exists(os.path.dirname(path)):
             try:
                 os.makedirs(os.path.dirname(path))
@@ -156,7 +156,7 @@ class Manager:
         try:
             copy2(new_path, secure_path)
         except Exception as e:
-            raise Exception(
+            raise FileExistsError(
                 f"Cannot copied here {secure_path}, file probabily exist {path} {str(e)}"
             )
         print(f"File copied here {secure_path}")
@@ -171,7 +171,7 @@ class Manager:
         )
         history_path = os.path.join(prod_dir, history_filename)
         if not os.path.exists(path):
-            raise Exception(f"file doesn't exist {path}")
+            raise FileNotFoundError(f"file doesn't exist {path}")
         if not os.path.exists(os.path.dirname(new_path)):
             try:
                 os.makedirs(os.path.dirname(new_path))
@@ -186,16 +186,13 @@ class Manager:
 
     def __del_file_in_prod(self, path):
         if path.find(self.__production_path) == -1:
-            raise Exception(
+            raise FileNotFoundError(
                 f"Cannot delte file {path} it's in other folder than {self.__production_path}"
             )
         if os.path.exists(path):
             os.remove(path)
         else:
-            raise Exception(f"File {path} not Found")
-
-    def get_prod(self, path):
-        self.__copy_file_in_dev(path)
+            raise FileNotFoundError(f"File {path} not Found")
 
     def get_out_path(self, path):
         filename = os.path.basename(path)
@@ -203,18 +200,32 @@ class Manager:
         out_path = os.path.join(dirname, f"out_{filename}")
         return out_path
 
+    def get_prod(self, path):
+        current_file = self.get_path(path)
+        self.__copy_file_in_dev(current_file)
+        print(
+            "🕣 Your Notebook from production folder has been copied into your dev folder.\n"
+        )
+
     def get_output(self, path):
         out_path = self.get_out_path(path)
         self.__copy_file_in_dev(out_path)
+        print(
+            "🕣 Your Notebook OUTPUT from production folder has been copied into your dev folder\n"
+        )
 
     def clear_output(self, path):
         out_path = self.get_out_path(path)
-        print(f"Delete {out_path}")
-        os.remove(out_path)
+        if os.path.exists(out_path):
+            os.remove(out_path)
+            print("🕣 Your Notebook output has been remove from production folder.\n")
+        else:
+            raise FileNotFoundError(f"File {out_path} not Found")
 
     def list_history(self, path):
-        prod_path = self.get_prod_path(path)
-        filename = os.path.basename(path)
+        current_file = self.get_path(path)
+        prod_path = self.get_prod_path(current_file)
+        filename = os.path.basename(current_file)
         dirname = os.path.dirname(prod_path)
         print("Avaliable :\n")
         for ffile in os.listdir(dirname):
@@ -228,15 +239,19 @@ class Manager:
                 print(histo + "\n")
 
     def get_history(self, path, histo):
-        filename = os.path.basename(path)
-        dirname = os.path.dirname(path)
+        current_file = self.get_path(path)
+        filename = os.path.basename(current_file)
+        dirname = os.path.dirname(current_file)
         path_histo = os.path.join(dirname, f"{histo}_{filename}")
         self.__copy_file_in_dev(path_histo)
 
     def clear_history(self, path, histo=None):
-        prod_path = self.get_prod_path(path)
+        current_file = self.get_path(path)
+        prod_path = self.get_prod_path(current_file)
         filename = (
-            os.path.basename(path) if not histo else f"{histo}_{os.path.basename(path)}"
+            os.path.basename(current_file)
+            if not histo
+            else f"{histo}_{os.path.basename(current_file)}"
         )
         dirname = os.path.dirname(prod_path)
         for ffile in os.listdir(dirname):
@@ -267,7 +282,9 @@ class Manager:
                 print(self.__error_manager_reject, e)
             return new_obj
         else:
-            raise Exception('obj should have all keys ("type","path","params","value")')
+            raise ValueError(
+                'obj should have all keys ("type","path","params","value")'
+            )
 
     def del_prod(self, obj, silent):
         if "type" in obj and "path" in obj:
@@ -289,4 +306,4 @@ class Manager:
                 print(self.__error_manager_reject, e)
             return new_obj
         else:
-            raise Exception('obj should have keys ("type","path")')
+            raise ValueError('obj should have keys ("type","path")')
