@@ -10,40 +10,18 @@ class AssetsController(HTTPMethodView):
     __logger = None
     __jobs = None
     __path_lib_files = None
-    __path_html_error = None
-    __assets_files = "assets"
-    __html_files = "html"
-    __manager_error = "error.html"
+    __assets_folder = "assets"
 
     def __init__(self, logger, jobs, path_assets, *args, **kwargs):
         super(AssetsController, self).__init__(*args, **kwargs)
         self.__logger = logger
         self.__jobs = jobs
         self.__path_lib_files = path_assets
-        self.__path_html_error = os.path.join(
-            self.__path_lib_files, self.__html_files, self.__manager_error
-        )
-        print("self.__path_html_error", self.__path_html_error)
-
-    def __html_error(self, content):
-        try:
-            with open(self.__path_html_error, "r") as f:
-                template = f.read()
-                f.close()
-                return template.replace("{ERROR}", content)
-        except Exception:
-            print("Cannot get html error")
-            return ""
 
     async def get(self, request, token):
-        if token == "up" or token == "down" or token.startswith("naas_"):
-            ext = ".png"
-            if token.startswith("naas_"):
-                ext = ".svg"
+        if token.startswith("naas_"):
             return await response.file(
-                os.path.join(
-                    self.__path_lib_files, self.__assets_files, f"{token}{ext}"
-                )
+                os.path.join(self.__path_lib_files, self.__assets_folder, token)
             )
         else:
             uid = str(uuid.uuid4())
