@@ -92,7 +92,7 @@ class Notebooks:
             result_type = mime_html
             file_filepath_out = self.get_out_path(filepath)
             (result, ressources) = self.__html_exporter.from_filename(file_filepath_out)
-        except:  # noqa: E722
+        except FileNotFoundError:  # noqa: E722
             tb = traceback.format_exc()
             result_type = mime_json
             result = {
@@ -110,37 +110,33 @@ class Notebooks:
             with open(path, "r") as f:
                 result = f.read()
                 f.close()
-        except:  # noqa: E722
+        except FileNotFoundError:  # noqa: E722
             result_type = mime_json
             result = {"error": "file not found"}
         return result_type, result
 
     def __check_output(self, output, filepath):
-        result = None
-        result_type = None
         metadata = output.get("metadata", [])
         data = output.get("data", dict())
-        for meta in metadata:
-            if metadata[meta].get("naas_api"):
-                if (
-                    data.get("text/markdown")
-                    and metadata[meta].get("naas_type") == t_notebook
-                ):
-                    (result_type, result) = self.__nb_render(filepath)
-                elif data.get(mime_json) and metadata[meta].get("naas_type"):
-                    (result_type, result) = self.__nb_file(metadata[meta], data)
-                elif data.get(mime_html) and metadata[meta].get("naas_type") == "csv":
-                    result_type = "text/csv"
-                    result = self.__convert_csv(data.get(mime_html))
-                elif data.get(mime_json):
-                    result_type = mime_json
-                    result = json.dumps(data.get(result_type))
-                else:
-                    result_type = next((i for i in mime_list if data.get(i)), None)
-                    result = data.get(result_type)
-                if result is not None or result_type is not None:
-                    return result_type, result
-        return result_type, result
+        meta_filtered = list(
+            filter(lambda meta: metadata[meta].get("naas_api"), metadata)
+        )
+        for meta in meta_filtered:
+            if (
+                data.get("text/markdown")
+                and metadata[meta].get("naas_type") == t_notebook
+            ):
+                return self.__nb_render(filepath)
+            elif data.get(mime_json) and metadata[meta].get("naas_type"):
+                return self.__nb_file(metadata[meta], data)
+            elif data.get(mime_html) and metadata[meta].get("naas_type") == "csv":
+                return "text/csv", self.__convert_csv(data.get(mime_html))
+            elif data.get(mime_json):
+                return mime_json, json.dumps(data.get(mime_json))
+            else:
+                result_type = next((i for i in mime_list if data.get(i)), None)
+                return result_type, data.get(result_type)
+        return None, None
 
     def __get_res(self, res, filepath):
         cells = res.get("cells")
@@ -148,13 +144,14 @@ class Notebooks:
             outputs = cell.get("outputs", [])
             for output in outputs:
                 (result_type, result) = self.__check_output(output, filepath)
-                if result is not None or result_type is not None:
+                if result is not None and result_type is not None:
                     return {"type": result_type, "data": result}
         return None
 
-    def __pm_exec(self, file_dirpath, file_filepath, file_filepath_out, params):
+    def __pm_exec(self, uid, file_dirpath, file_filepath, file_filepath_out, params):
+        res = None
         if kern_manager:
-            return pm.execute_notebook(
+            res = pm.execute_notebook(
                 input_path=file_filepath,
                 output_path=file_filepath_out,
                 progress_bar=False,
@@ -163,13 +160,56 @@ class Notebooks:
                 kernel_manager_class=kern_manager,
             )
         else:
-            return pm.execute_notebook(
+            res = pm.execute_notebook(
                 input_path=file_filepath,
                 output_path=file_filepath_out,
                 progress_bar=False,
                 cwd=file_dirpath,
                 parameters=params,
             )
+        if not res:
+            res = {"error": "Unknow error"}
+            self.__logger.error(
+                {
+                    "id": uid,
+                    "type": "Exception",
+                    "status": t_error,
+                    "filepath": file_filepath,
+                    "output_filepath": file_filepath_out,
+                    "error": res["error"],
+                }
+            )
+        else:
+            self.__logger.info(
+                {
+                    "id": uid,
+                    "type": "Done",
+                    "status": t_health,
+                    "filepath": file_filepath,
+                    "output_filepath": file_filepath_out,
+                }
+            )
+        return res
+
+    def __send_notification(self, uid, res, file_filepath, current_type, value, params):
+        notif_down = params.get("notif_down", None)
+        notif_up = params.get("notif_up", None)
+        if res.get("error"):
+            email_admin = os.environ.get("JUPYTERHUB_USER", None)
+            if email_admin is not None:
+                self.__notif.send_status(
+                    uid, "down", email_admin, file_filepath, current_type, value
+                )
+            if notif_down and self.__notif:
+                self.__notif.send_status(
+                    uid, "down", notif_down, file_filepath, current_type, value
+                )
+        elif notif_up and current_type == t_scheduler and self.__notif:
+            self.__notif.send_status(
+                uid, "up", notif_down, file_filepath, current_type, value
+            )
+        elif notif_up and self.__notif:
+            self.__notif.send_status(uid, "up", notif_up, file_filepath, current_type)
 
     def __get_output_path(self, file_filepath):
         file_dirpath = os.path.dirname(file_filepath)
@@ -196,13 +236,13 @@ class Notebooks:
         file_dirpath = os.path.dirname(file_filepath)
         file_filepath_out = self.__get_output_path(file_filepath)
         params = job.get("params", dict())
-        notif_down = params.get("notif_down", None)
-        notif_up = params.get("notif_up", None)
         params["run_uid"] = uid
         start_time = time.time()
         res = None
         try:
-            res = self.__pm_exec(file_dirpath, file_filepath, file_filepath_out, params)
+            res = self.__pm_exec(
+                uid, file_dirpath, file_filepath, file_filepath_out, params
+            )
         except pm.PapermillExecutionError as err:
             tb = traceback.format_exc()
             res = {"error": err, "traceback": str(tb)}
@@ -244,43 +284,6 @@ class Notebooks:
                     "traceback": str(tb),
                 }
             )
-        if not res:
-            res = {"error": "Unknow error"}
-            self.__logger.error(
-                {
-                    "id": uid,
-                    "type": "Exception",
-                    "status": t_error,
-                    "filepath": file_filepath,
-                    "output_filepath": file_filepath_out,
-                    "error": res["error"],
-                }
-            )
-        else:
-            self.__logger.info(
-                {
-                    "id": uid,
-                    "type": "Done",
-                    "status": t_health,
-                    "filepath": file_filepath,
-                    "output_filepath": file_filepath_out,
-                }
-            )
         res["duration"] = time.time() - start_time
-        if res.get("error"):
-            email_admin = os.environ.get("JUPYTERHUB_USER", None)
-            if email_admin is not None:
-                self.__notif.send_status(
-                    uid, "down", email_admin, file_filepath, current_type, value
-                )
-            if notif_down and self.__notif:
-                self.__notif.send_status(
-                    uid, "down", notif_down, file_filepath, current_type, value
-                )
-        elif notif_up and current_type == t_scheduler and self.__notif:
-            self.__notif.send_status(
-                uid, "up", notif_down, file_filepath, current_type, value
-            )
-        elif notif_up and self.__notif:
-            self.__notif.send_status(uid, "up", notif_up, file_filepath, current_type)
+        self.__send_notification(uid, res, file_filepath, current_type, value, params)
         return res
